# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`windows_drives`](#windows_drives): Windows Drives

#### Private Classes

* `windows_drives::config`: Configuration

### Defined types

* [`windows_drives::defines::drive`](#windows_drives--defines--drive): Drive
* [`windows_drives::defines::shadow_copy`](#windows_drives--defines--shadow_copy): Shadow Copy
* [`windows_drives::defines::trigger`](#windows_drives--defines--trigger): Trigger

## Classes

### <a name="windows_drives"></a>`windows_drives`

Manages Microsoft Windows drives

#### Examples

##### 

```puppet
include windows_drives
```

#### Parameters

The following parameters are available in the `windows_drives` class:

* [`drives`](#-windows_drives--drives)
* [`log_output`](#-windows_drives--log_output)
* [`shadow_copies`](#-windows_drives--shadow_copies)

##### <a name="-windows_drives--drives"></a>`drives`

Data type: `Array[Hash]`

Array of hashes containing drive configurations
Example: [
  {
    letter: 'E',
    label: 'Example01',
    indexing: 'false',
  },
]

Default value: `[]`

##### <a name="-windows_drives--log_output"></a>`log_output`

Data type: `Boolean`

Boolean used to enable additional logging output
Example: true

Default value: `false`

##### <a name="-windows_drives--shadow_copies"></a>`shadow_copies`

Data type: `Array[Hash]`

Array of hashes containing shadow copy configurations
   Split out from $drives to help flatten heira data structure
Example: [
  {
    letter: 'E',
    on: 'E',
    auto_retry_minutes: 25,
    ensure: 'present',
    max_size: 4224,
    triggers: [
      {
        at: '11:45pm',
        days_of_week: ['Friday'],
        weeks_interval: 3,
      },
      {
        at: '8:15am',
        days_of_week: ['Monday', 'Wednesday'],
        weeks_interval: 1,
      },
    ],
  },
]

Default value: `[]`

## Defined types

### <a name="windows_drives--defines--drive"></a>`windows_drives::defines::drive`

Defines a Windows drive

#### Parameters

The following parameters are available in the `windows_drives::defines::drive` defined type:

* [`indexing`](#-windows_drives--defines--drive--indexing)
* [`label`](#-windows_drives--defines--drive--label)
* [`letter`](#-windows_drives--defines--drive--letter)

##### <a name="-windows_drives--defines--drive--indexing"></a>`indexing`

Data type: `Enum['true', 'false', 'unmanaged']`

Enumerated string denoting if Indexing should be enabled on the drive
   Allow time for indexing service changes to fully process if there is data on the drive
Example: 'true'

Default value: `'unmanaged'`

##### <a name="-windows_drives--defines--drive--label"></a>`label`

Data type: `Optional[String]`

String containing the text to use as the label on the drive
Example: 'DataDisk'

Default value: `undef`

##### <a name="-windows_drives--defines--drive--letter"></a>`letter`

Data type:

```puppet
Enum['A', 'B', 'C', 'D', 'E', 'F',
    'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N',
    'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V',
  'W', 'X', 'Y', 'Z']
```

Enumerated string containing the letter of the drive to configure
Example: 'E'

### <a name="windows_drives--defines--shadow_copy"></a>`windows_drives::defines::shadow_copy`

Defines a Windows drive shadow copy configuration

#### Parameters

The following parameters are available in the `windows_drives::defines::shadow_copy` defined type:

* [`auto_retry_minutes`](#-windows_drives--defines--shadow_copy--auto_retry_minutes)
* [`ensure`](#-windows_drives--defines--shadow_copy--ensure)
* [`letter`](#-windows_drives--defines--shadow_copy--letter)
* [`max_size`](#-windows_drives--defines--shadow_copy--max_size)
* [`max_size_type`](#-windows_drives--defines--shadow_copy--max_size_type)
* [`on`](#-windows_drives--defines--shadow_copy--on)
* [`task_compatibility`](#-windows_drives--defines--shadow_copy--task_compatibility)
* [`task_execution_time_limit`](#-windows_drives--defines--shadow_copy--task_execution_time_limit)
* [`task_priority`](#-windows_drives--defines--shadow_copy--task_priority)
* [`triggers`](#-windows_drives--defines--shadow_copy--triggers)

##### <a name="-windows_drives--defines--shadow_copy--auto_retry_minutes"></a>`auto_retry_minutes`

Data type: `Integer`

The maximum amount of time (in minutes) to attempt to create the shadow copy
Example: 25

Default value: `15`

##### <a name="-windows_drives--defines--shadow_copy--ensure"></a>`ensure`

Data type: `Enum['absent', 'present', 'unmanaged']`

denotes the desired state of shadow copy for the supplied drive letter
Example: 'present'

Default value: `'unmanaged'`

##### <a name="-windows_drives--defines--shadow_copy--letter"></a>`letter`

Data type:

```puppet
Enum['A', 'B', 'C', 'D', 'E', 'F',

    'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N',

    'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V',

  'W', 'X', 'Y', 'Z']
```

Enumerated string containing the letter of the drive to configure
Example: 'E'

##### <a name="-windows_drives--defines--shadow_copy--max_size"></a>`max_size`

Data type: `Integer`

Denotes the maximum amount of storage space to consume
   If limited, must be 300 MB or greater
   Do not set if wanting Unlimited
Example: 450

Default value: `undef`

##### <a name="-windows_drives--defines--shadow_copy--max_size_type"></a>`max_size_type`

Data type: `Enum['bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB']`

Denotes the type of max_size value supplied
Example: 'GB'

Default value: `'MB'`

##### <a name="-windows_drives--defines--shadow_copy--on"></a>`on`

Data type:

```puppet
Enum['A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J',

    'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U',

  'V', 'W', 'X', 'Y', 'Z']
```

Enumerated string containing the letter of the drive to store the shadow copy
Example: 'K'

Default value: `$letter`

##### <a name="-windows_drives--defines--shadow_copy--task_compatibility"></a>`task_compatibility`

Data type: `Enum['At', 'V1', 'Vista', 'Win7', 'Win8']`

String containing the compatibiltiy type for the associated scheduled task
Example: 'Win8'

Default value: `'V1'`

##### <a name="-windows_drives--defines--shadow_copy--task_execution_time_limit"></a>`task_execution_time_limit`

Data type: `Enum['1H', '2H', '4H', '8H', '12H', '1D', '3D']`

String of the amount of time that the associated scheduled task is allowed for completion
   D=Days, H=Hours
Example: '4H'

Default value: `'8H'`

##### <a name="-windows_drives--defines--shadow_copy--task_priority"></a>`task_priority`

Data type: `Integer[0,10]`

The priority level given to the asssociated scheduled task
Example: 5

Default value: `7`

##### <a name="-windows_drives--defines--shadow_copy--triggers"></a>`triggers`

Data type: `Array[Hash]`

Array of hashes containing the scheduled task trigger configurations
Example: [
  {
    at: '11:45pm',
    days_of_week: ['Friday'],
    weeks_interval: 3,
  },
  {
    at: '8:15am',
    days_of_week: ['Monday', 'Wednesday'],
    weeks_interval: 1,
  },
],

Default value: `[]`

### <a name="windows_drives--defines--trigger"></a>`windows_drives::defines::trigger`

Defines a Windows drive shadow copy scheduled task trigger

#### Parameters

The following parameters are available in the `windows_drives::defines::trigger` defined type:

* [`at`](#-windows_drives--defines--trigger--at)
* [`days_of_week`](#-windows_drives--defines--trigger--days_of_week)
* [`weeks_interval`](#-windows_drives--defines--trigger--weeks_interval)

##### <a name="-windows_drives--defines--trigger--at"></a>`at`

Data type: `String`

String containing the time to trigger the task
Example: '10:15am'

##### <a name="-windows_drives--defines--trigger--days_of_week"></a>`days_of_week`

Data type: `Array[String]`

Array of strings denoting the days of the week on which to run the task
Example: ['Monday', 'Wednesday', 'Friday']

Default value: `[]`

##### <a name="-windows_drives--defines--trigger--weeks_interval"></a>`weeks_interval`

Data type: `Integer[1,25]`

Integer denoting the interval between the weeks in the schedule for the task
Example: 3

Default value: `1`

