# @summary Drive
#
# Defines a Windows drive
#
# @param indexing
#   Enumerated string denoting if Indexing should be enabled on the drive
#      Allow time for indexing service changes to fully process if there is data on the drive
#   Example: 'true'
#
# @param label
#   String containing the text to use as the label on the drive
#   Example: 'DataDisk'
#
# @param letter
#   Enumerated string containing the letter of the drive to configure
#   Example: 'E'
#
define windows_drives::defines::drive (
  Enum['A', 'B', 'C', 'D', 'E', 'F',
    'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N',
    'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V',
  'W', 'X', 'Y', 'Z'] $letter,
  Enum['true', 'false', 'unmanaged'] $indexing = 'unmanaged',
  Optional[String] $label = undef,
) {
  if ($windows_drives::log_output) {
    notify { "${module_name} - drive - letter: '${letter}'": }
    notify { "${module_name} - drive - indexing: '${indexing}'": }
    notify { "${module_name} - drive - label: '${label}'": }
  }
  if ($label) {
    exec { "Set label for the ${letter} drive":
      provider => powershell,
      command  => "\$drive = Get-WmiObject -ClassName Win32_Volume -Filter \"DriveLetter = '${letter}:'\"
                  \$drive | Set-WmiInstance -Property @{Label='${label}'}",
      onlyif   => "\$drive = Get-WmiObject -ClassName Win32_Volume -Filter \"DriveLetter = '${letter}:'\"
                  if (\"\$(\$drive.Label)\" -eq '${label}') {
                    exit 1
                  }
                  exit 0",
    }
  }
  if ($indexing == 'true' or $indexing == 'false') {
    exec { "Set indexing for the ${letter} drive":
      provider => powershell,
      command  => "\$drive = Get-WmiObject -ClassName Win32_Volume -Filter \"DriveLetter = '${letter}:'\"
                  \$drive | Set-WmiInstance -Property @{IndexingEnabled='${indexing}'}",
      onlyif   => "\$drive = Get-WmiObject -ClassName Win32_Volume -Filter \"DriveLetter = '${letter}:'\"
                  if (\"\$(\$drive.IndexingEnabled)\" -eq '${indexing}') {
                    exit 1
                  }
                  exit 0",
    }
  }
}
