# @summary Trigger
#
# Defines a Windows drive shadow copy scheduled task trigger
#
# @param at
#   String containing the time to trigger the task
#   Example: '10:15am'
#
# @param days_of_week
#   Array of strings denoting the days of the week on which to run the task
#   Example: ['Monday', 'Wednesday', 'Friday']
#
# @param weeks_interval
#   Integer denoting the interval between the weeks in the schedule for the task
#   Example: 3
#
define windows_drives::defines::trigger (
  String $at,
  Array[String] $days_of_week = [],
  Integer[1,25] $weeks_interval = 1,
) {
  if ($windows_drives::log_output) {
    notify { "${module_name} - trigger - ${title} - at: '${at}'": }
    notify { "${module_name} - trigger - ${title} - days_of_week: '${days_of_week}'": }
    notify { "${module_name} - trigger - ${title} - weeks_interval: '${weeks_interval}'": }
  }
  $all_days_of_week = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday']
  $days_of_week.each | String $day | {
    if !($day in $all_days_of_week) {
      fail "Invalid day of week: ${day}"
    }
  }
}
