# @summary Windows Drives
#
# Manages Microsoft Windows drives
#
# @param drives
#   Array of hashes containing drive configurations
#   Example: [
#     {
#       letter: 'E',
#       label: 'Example01',
#       indexing: 'false',
#     },
#   ]
#
# @param log_output
#   Boolean used to enable additional logging output
#   Example: true
#
# @param shadow_copies
#   Array of hashes containing shadow copy configurations
#      Split out from $drives to help flatten heira data structure
#   Example: [
#     {
#       letter: 'E',
#       on: 'E',
#       auto_retry_minutes: 25,
#       ensure: 'present',
#       max_size: 4224,
#       triggers: [
#         {
#           at: '11:45pm',
#           days_of_week: ['Friday'],
#           weeks_interval: 3,
#         },
#         {
#           at: '8:15am',
#           days_of_week: ['Monday', 'Wednesday'],
#           weeks_interval: 1,
#         },
#       ],
#     },
#   ]
#
# @example
#   include windows_drives
class windows_drives (
  Array[Hash] $drives = [],
  Array[Hash] $shadow_copies = [],
  Boolean $log_output = false,
) {
  include windows_drives::config
}
